==> bibmanager-1.3.4.tar.gz: bibmanager-1.3.4/README.md <==
# bibmanager
> The Next Standard in BibTeX Management


[![Build Status](https://travis-ci.com/pcubillos/bibmanager.svg?branch=master)](https://travis-ci.com/pcubillos/bibmanager)
[![Documentation Status](https://readthedocs.org/projects/bibmanager/badge/?version=latest)](https://bibmanager.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/bibmanager.svg)](https://pypi.org/project/bibmanager)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/bibmanager.svg)](https://anaconda.org/conda-forge/bibmanager)
[![GitHub](https://img.shields.io/github/license/pcubillos/bibmanager.svg?color=blue)](https://bibmanager.readthedocs.io/en/latest/license.html)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2547042.svg)](https://doi.org/10.5281/zenodo.2547042)

### Install as:
```
pip install bibmanager
```
or:
```
conda install -c conda-forge bibmanager
```

### Docs at:
<https://bibmanager.readthedocs.io/en/latest/>

### Cite as:
```bibtex
  @MISC{Cubillos2019zndoBibmanager,
         author = {{Cubillos}, Patricio E.},
          title = "{bibmanager: A BibTeX manager for LaTeX projects}",
           year = 2019,
          month = Apr,
            eid = {10.5281/zenodo.2547042},
            doi = {10.5281/zenodo.2547042},
      publisher = {Zenodo},
         url    = {https://doi.org/10.5281/zenodo.2547042},
         adsurl = {https://ui.adsabs.harvard.edu/abs/2019zndo...2547042C},
        adsnote = {Provided by the SAO/NASA Astrophysics Data System},
  }
```

# <img alt="bibmanager" src="https://github.com/pcubillos/bibmanager/blob/master/docs/infograph.png" width="535">

==> bibmanager-1.4.4.tar.gz: bibmanager-1.4.4/README.md <==
# bibmanager
> The Next Standard in BibTeX Management

[![Tests](https://github.com/pcubillos/bibmanager/actions/workflows/python-package.yml/badge.svg?branch=master)](https://github.com/pcubillos/bibmanager/actions/workflows/python-package.yml)
[![Documentation Status](https://readthedocs.org/projects/bibmanager/badge/?version=latest)](https://bibmanager.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/bibmanager.svg)](https://pypi.org/project/bibmanager)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/bibmanager.svg)](https://anaconda.org/conda-forge/bibmanager)
[![GitHub](https://img.shields.io/github/license/pcubillos/bibmanager.svg?color=blue)](https://bibmanager.readthedocs.io/en/latest/license.html)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2547042.svg)](https://doi.org/10.5281/zenodo.2547042)

### Install as:
```
pip install bibmanager
```
or:
```
conda install -c conda-forge bibmanager
```

### Docs at:
<https://bibmanager.readthedocs.io/en/latest/>

### Cite as:
```bibtex
  @MISC{Cubillos2020zndoBibmanager,
         author = {{Cubillos}, Patricio E.},
          title = "{bibmanager: A BibTeX manager for LaTeX projects}",
           year = 2020,
          month = feb,
   howpublished = {Zenodo},
            eid = {10.5281/zenodo.2547042},
            doi = {10.5281/zenodo.2547042},
      publisher = {Zenodo},
         url    = {https://doi.org/10.5281/zenodo.2547042},
         adsurl = {https://ui.adsabs.harvard.edu/abs/2020zndo...2547042C},
        adsnote = {Provided by the SAO/NASA Astrophysics Data System},
  }
```

# <img alt="bibmanager" src="https://github.com/pcubillos/bibmanager/blob/master/docs/infograph.png" width="535">
